##パッケージのインストール

install.packages("jpmesh", dependencies=TRUE)
install.packages("ggthemes", dependencies=TRUE)
install.packages("viridis", dependencies=TRUE)

library(jpmesh)
library(dplyr, warn.conflicts=FALSE)
library(ggplot2)
library(ggthemes)
library(mapproj)
library(knitr)
library(viridis)


##########################################


#メッシュコードからメッシュ範囲特定のための緯度経度の取得
meshcode_to_latlon(5133)
meshcode_to_latlon(513377)
meshcode_to_latlon(51337783)

#緯度経度から、範囲内のメッシュコードを取得
latlong_to_meshcode(34, 133, order = 1)
latlong_to_meshcode(34.583333, 133.875, order = 2)
latlong_to_meshcode(34.65, 133.9125, order = 3)

#Detect fine mesh code (より小さいメッシュコードの取得)
detect_mesh(52350422, lat = 34.684176, long = 135.526130)
detect_mesh(523504221, lat = 34.684028, long = 135.529506)


#1次メッシュを基礎とした単純化した日本地図の描画
data("jpnrect")

ggplot() +
  geom_map(data = jpnrect,
           map  = jpnrect,
           aes(x = long, y = lat, map_id = id),
           fill = "white", color = "black",
           size = 1) +
  coord_map() +
  ggthemes::theme_map() +
  geom_text(aes(x = longitude, y = latitude, label = abb_name), data = jpnrect, size = 10)


# 都道府県別のメッシュコードデータ
pref_mesh(47) %>% head() %>% knitr::kable()


##########################################


# モバイル空間統計データ読み込み
mobile_stat <- read.csv("201608_DAY_JP_1km_Pop.csv")
mobile20160827400 <- subset(mobile_stat, date==20160826 & time==400)


#write.csv(mobile20160827400,"mobile400.csv")

# 沖縄本島市区町村コード
honto_list <- c(47201, 47205, 47208, 47209, 47210, 47211, 47212, 
                47213, 47215, 47301, 47302, 47303, 47306, 47308, 
                47311, 47313, 47314, 47315, 47324, 47325, 47326, 
                47327, 47328, 47329)

honto_list
# 沖縄本島のメッシュだけを抽出
honto_mesh0 <- subset(pref_mesh(47), city_code %in% honto_list)


##########################################

# メッシュの枠を作成
df.map <- honto_mesh0 %>% 
  mutate(mesh_area = purrr::map(id, meshcode_to_latlon)) %>% 
  tidyr::unnest() %>% 
  mutate(lng1 = long_center - long_error,
         lat1 = lat_center - lat_error,
         lng2 = long_center + long_error,
         lat2 = lat_center + lat_error)

ggplot() + 
  geom_map(data = df.map, 
           map = df.map,
           aes(x = long, y = lat, map_id = id), 
           fill = "white", color = "black") + 
  coord_map(projection = "mercator") -> plot_map

# メッシュの枠を表示
plot_map 

##############################################

# モバ空データのヒートマップ表示

df.map.mobile <- merge(df.map, mobile20160827400,
                       by.x ="id", by.y = "area", all.x =T)

plot_map + 
  geom_map(data = df.map.mobile, 
           map = df.map,
           aes(fill = population, map_id = id, stat = "identity")) +
  scale_fill_viridis(option="plasma")


##########################################

#宿泊者数データ数データでも同様に

syukuhaku <- read.csv("syukuhaku.csv")

#メッシュの枠は上記のものと同じ

#宿泊者数データのヒートマップ表示

df.map.syukuhaku <- merge(df.map,syukuhaku,
                          by.x ="id", by.y = "P09_001", all.x =T)

plot_map + 
  geom_map(data = df.map.syukuhaku, 
           map = df.map,
           aes(fill = P09_013 , map_id = id, stat = "identity")) +
  scale_fill_viridis(option="plasma")


##########################################


#回帰分析


match<-read.csv("match400.csv")

result<-lm(population ~ syukuhaku, data = match)


summary(result)

plot(match$syukuhaku,match$population)
abline(result) 
